@@ -11,8 +11,8 @@
 guiqwt.baseplot
 ---------------
 
-The `baseplot` module provides the `guiqwt` plotting widget base class: 
-:py:class:`guiqwt.baseplot.BasePlot`. This is an enhanced version of 
+The `baseplot` module provides the `guiqwt` plotting widget base class:
+:py:class:`guiqwt.baseplot.BasePlot`. This is an enhanced version of
 `PythonQwt`'s QwtPlot plotting widget which supports the following features:
 
     * add to plot, del from plot, hide/show and save/restore `plot items` easily
@@ -21,20 +21,20 @@ The `baseplot` module provides the `guiqwt` plotting widget base class:
     * plot parameters editing
 
 .. warning::
-    :py:class:`guiqwt.baseplot.BasePlot` is rather an internal class 
-    than a ready-to-use plotting widget. The end user should prefer using 
+    :py:class:`guiqwt.baseplot.BasePlot` is rather an internal class
+    than a ready-to-use plotting widget. The end user should prefer using
     :py:class:`guiqwt.plot.CurvePlot` or :py:class:`guiqwt.plot.ImagePlot`.
 
 .. seealso::
-    
+
     Module :py:mod:`guiqwt.curve`
         Module providing curve-related plot items and plotting widgets
-        
+
     Module :py:mod:`guiqwt.image`
         Module providing image-related plot items and plotting widgets
-        
+
     Module :py:mod:`guiqwt.plot`
-        Module providing ready-to-use curve and image plotting widgets and 
+        Module providing ready-to-use curve and image plotting widgets and
         dialog boxes
 
 Reference
@@ -45,17 +45,13 @@ Reference
    :inherited-members:
 """
 
-from __future__ import print_function
-
 import sys
 import numpy as np
 
 from qtpy.QtWidgets import QSizePolicy, QApplication
 from qtpy.QtPrintSupport import QPrinter
-from qtpy.QtGui import QColor, QPixmap
+from qtpy.QtGui import QColor
 from qtpy.QtCore import QSize, Qt, Signal
-from qtpy import PYQT5
-from qtpy.py3compat import to_text_string, is_text_string, maxsize
 
 from guidata.configtools import get_font
 
@@ -105,9 +101,9 @@ class BasePlot(QwtPlot):
     """
     An enhanced QwtPlot class that provides
     methods for handling plotitems and axes better
-    
+
     It distinguishes activatable items from basic QwtPlotItems.
-    
+
     Activatable items must support IBasePlotItem interface and should
     be added to the plot using add_item methods.
     """
@@ -234,7 +230,7 @@ class BasePlot(QwtPlot):
 
     def get_title(self):
         """Get plot title"""
-        return to_text_string(self.title().text())
+        return str(self.title().text())
 
     def set_title(self, title):
         """Set plot title"""
@@ -253,7 +249,7 @@ class BasePlot(QwtPlot):
         """
         Read axes styles from section and options (one option
         for each axis in the order left, right, bottom, top)
-        
+
         Skip axis if option is None
         """
         for prm, option in zip(self.axes_styles, options):
@@ -307,7 +303,7 @@ class BasePlot(QwtPlot):
         color: color name (string) or QColor instance
         """
         axis_id = self.get_axis_id(axis_id)
-        if is_text_string(color):
+        if isinstance(color, str):
             color = QColor(color)
         self.axes_styles[axis_id].color = str(color.name())
         self.update_axis_style(axis_id)
@@ -444,15 +440,12 @@ class BasePlot(QwtPlot):
     def copy_to_clipboard(self):
         """Copy widget's window to clipboard"""
         clipboard = QApplication.clipboard()
-        if PYQT5:
-            pixmap = self.grab()
-        else:
-            pixmap = QPixmap.grabWidget(self)
+        pixmap = self.grab()
         clipboard.setPixmap(pixmap)
 
     def save_widget(self, fname):
         """Grab widget's window and save it to filename (\*.png, \*.pdf)"""
-        fname = to_text_string(fname)
+        fname = str(fname)
         if fname.lower().endswith(".pdf"):
             printer = QPrinter()
             printer.setOutputFormat(QPrinter.PdfFormat)
@@ -461,10 +454,7 @@ class BasePlot(QwtPlot):
             printer.setCreator("guidata")
             self.print_(printer)
         elif fname.lower().endswith(".png"):
-            if PYQT5:
-                pixmap = self.grab()
-            else:
-                pixmap = QPixmap.grabWidget(self)
+            pixmap = self.grab()
             pixmap.save(fname, "PNG")
         else:
             raise RuntimeError(_("Unknown file extension"))
@@ -490,7 +480,7 @@ class BasePlot(QwtPlot):
     def add_item(self, item, z=None):
         """
         Add a *plot item* instance to this *plot widget*
-        
+
         item: :py:data:`qwt.QwtPlotItem` object implementing
               the IBasePlotItem interface (guiqwt.interfaces)
         """
@@ -520,7 +510,7 @@ class BasePlot(QwtPlot):
         if len(dzlist) == 0:
             z = max(zlist) + 1
         else:
-            z = zlist[dzlist[0]] + 1
+            z = zlist[int(dzlist[0])] + 1
         self.add_item(item, z=z)
 
     def __clean_item_references(self, item):
@@ -591,7 +581,7 @@ class BasePlot(QwtPlot):
         Save (serializable) items to file using the :py:mod:`pickle` protocol
             * iofile: file object or filename
             * selected=False: if True, will save only selected items
-            
+
         See also :py:meth:`guiqwt.baseplot.BasePlot.restore_items`
         """
         if selected:
@@ -607,7 +597,7 @@ class BasePlot(QwtPlot):
         """
         Restore items from file using the :py:mod:`pickle` protocol
             * iofile: file object or filename
-            
+
         See also :py:meth:`guiqwt.baseplot.BasePlot.save_items`
         """
         import pickle
@@ -621,7 +611,7 @@ class BasePlot(QwtPlot):
         Save (serializable) items to HDF5 file:
             * writer: :py:class:`guidata.hdf5io.HDF5Writer` object
             * selected=False: if True, will save only selected items
-            
+
         See also :py:meth:`guiqwt.baseplot.BasePlot.restore_items_from_hdf5`
         """
         if selected:
@@ -635,7 +625,7 @@ class BasePlot(QwtPlot):
         """
         Restore items from HDF5 file:
             * reader: :py:class:`guidata.hdf5io.HDF5Reader` object
-            
+
         See also :py:meth:`guiqwt.baseplot.BasePlot.save_items_to_hdf5`
         """
         for item in io.load_items(reader):
@@ -661,9 +651,9 @@ class BasePlot(QwtPlot):
     def move_up(self, item_list):
         """Move item(s) up, i.e. to the foreground
         (swap item with the next item in z-order)
-        
+
         item: plot item *or* list of plot items
-        
+
         Return True if items have been moved effectively"""
         objects = self.get_items(z_sorted=True)
         items = sorted(list(item_list), reverse=True, key=lambda x: objects.index(x))
@@ -680,9 +670,9 @@ class BasePlot(QwtPlot):
     def move_down(self, item_list):
         """Move item(s) down, i.e. to the background
         (swap item with the previous item in z-order)
-        
+
         item: plot item *or* list of plot items
-        
+
         Return True if items have been moved effectively"""
         objects = self.get_items(z_sorted=True)
         items = sorted(list(item_list), reverse=False, key=lambda x: objects.index(x))
@@ -796,15 +786,15 @@ class BasePlot(QwtPlot):
         Return nearest item from position 'pos'
 
         If close_dist > 0:
-            
-            Return the first found item (higher z) which distance to 'pos' is 
+
+            Return the first found item (higher z) which distance to 'pos' is
             less than close_dist
 
         else:
-            
+
             Return the closest item
         """
-        selobj, distance, inside, handle = None, maxsize, None, None
+        selobj, distance, inside, handle = None, sys.maxsize, None, None
         for obj in self.get_items(z_sorted=True):
             if not obj.isVisible() or not obj.can_select():
                 continue
@@ -824,7 +814,7 @@ class BasePlot(QwtPlot):
         Return nearest item for which position 'pos' is inside of it
         (iterate over items with respect to their 'z' coordinate)
         """
-        selobj, distance, inside, handle = None, maxsize, None, None
+        selobj, distance, inside, handle = None, sys.maxsize, None, None
         for obj in self.get_items(z_sorted=True):
             if not obj.isVisible() or not obj.can_select():
                 continue
@@ -860,7 +850,7 @@ class BasePlot(QwtPlot):
         """
         Return a list of DataSets for a given parameter key
         the datasets will be edited and passed back to set_plot_parameters
-        
+
         this is a generic interface to help building context menus
         using the BasePlotMenuTool
         """
