@@ -282,7 +282,8 @@ def add_fitparam_widgets_to(layout, fitparams, refresh_callback, param_cols=1):
     row_nb = 0
     col_nb = 0
     for i, param in enumerate(fitparams):
-        param.create_widgets(layout.parent(), refresh_callback)
+        if not param.get_widgets():
+            param.create_widgets(layout.parent(), refresh_callback)
         widgets = param.get_widgets()
         w_colums = len(widgets) + 1
         row_contents += [
@@ -507,6 +508,11 @@ class FitWidgetMixin(CurveWidgetMixin):
         plot.replot()
         if state:
             plot.set_active_item(self.xrange)
+        else:
+            #  If the button is unckeked then set to the complete range
+            self.autofit_prm.xmin = self.x.min()
+            self.autofit_prm.xmax = self.x.max()
+            self.xrange.set_range(self.autofit_prm.xmin, self.autofit_prm.xmax)
         self.show_xrange = state
 
     def edit_parameters(self):
