@@ -20,25 +20,21 @@ from guiqwt.tests import sift
 def create_executable():
     """Build executable using ``guidata.disthelpers``"""
     dist = Distribution()
-    dist.setup(name="Sift", version=sift.VERSION,
-               description="Signal and Image Filtering Tool",
-               script="sift.pyw", target_name="sift.exe",
-               target_dir="%s-%s" % ("Sift", sift.VERSION), icon="sift.ico")
-    dist.add_modules('guidata', 'guiqwt')
-    try:
-        import spyderlib
-        spyderlib.add_to_distribution(dist)
-    except ImportError:
-        try:
-            import spyder
-            spyder.add_to_distribution(dist)
-        except ImportError:
-            pass
-    dist.excludes += ['IPython']
+    dist.setup(
+        name="Sift",
+        version=sift.VERSION,
+        description="Signal and Image Filtering Tool",
+        script="sift.pyw",
+        target_name="sift.exe",
+        target_dir="%s-%s" % ("Sift", sift.VERSION),
+        icon="sift.ico",
+    )
+    dist.add_modules("guidata", "guiqwt")
+    dist.excludes += ["IPython"]
 
     # Building executable
-    dist.build('cx_Freeze', create_archive='move')
+    dist.build("cx_Freeze", create_archive="move")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     create_executable()
