@@ -4,24 +4,24 @@
   Licensed under the terms of the CECILL License
   (see guiqwt/__init__.py for details)
 
-  
-  Two lines of the following code are distributed under LGPL license terms and 
-  with a different copyright. These two lines are the Visual Studio x86_64 
-  (_M_X64) inline versions of lrint() and lrintf() functions, and were adapted 
+
+  Two lines of the following code are distributed under LGPL license terms and
+  with a different copyright. These two lines are the Visual Studio x86_64
+  (_M_X64) inline versions of lrint() and lrintf() functions, and were adapted
   from fast_convert.h (SpanDSP), which is:
 
   Copyright © 2009 Steve Underwood
   All rights reserved.
- 
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU Lesser General Public License version 2.1,
   as published by the Free Software Foundation.
- 
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU Lesser General Public License for more details.
-  
+
 */
 #ifndef __TRAITS_HPP__
 #define __TRAITS_HPP__
@@ -39,42 +39,46 @@
 
 /* MSVC does not have lrint/lrintf */
 #ifdef _MSC_VER
-    #include <intrin.h>
-    __inline long int lrint (double f)
-    {
-    #ifdef _M_X64
-        return (long int)_mm_cvtsd_si64x(_mm_loadu_pd((const double*)&f));
-    #else
-        int i; 
-        _asm
-        {
-            fld f
-            fistp i
-        }
-        return i;
-    #endif
-    }
+#if _MSC_VER < 1900 // (Visual Studio 2015 version 14.0)
 
-    __inline long int lrintf (float f)
+#include <intrin.h>
+__inline long int lrint(double f)
+{
+#ifdef _M_X64
+    return (long int)_mm_cvtsd_si64x(_mm_loadu_pd((const double *)&f));
+#else
+    int i;
+    _asm
     {
-    #ifdef _M_X64
-        return _mm_cvt_ss2si(_mm_load_ss((const float*)&f));
-    #else
-        int i;
-        _asm
-        {
-            fld f
-            fistp i
-        }
-        return i;
-    #endif
+                fld f
+                fistp i
     }
+    return i;
+#endif
+}
+
+__inline long int lrintf(float f)
+{
+#ifdef _M_X64
+    return _mm_cvt_ss2si(_mm_load_ss((const float *)&f));
+#else
+    int i;
+    _asm
+    {
+                fld f
+                fistp i
+    }
+    return i;
+#endif
+}
+#endif
 #endif
 
 typedef int fixed;
 
-template<typename T>
-struct num_trait {
+template <typename T>
+struct num_trait
+{
     typedef T value_type;
     typedef long large_type;
     static int toint(value_type v) { return (int)v; }
@@ -83,8 +87,9 @@ struct num_trait {
     static const bool is_integer = true;
 };
 
-template<>
-struct num_trait<float> {
+template <>
+struct num_trait<float>
+{
     typedef float value_type;
     typedef float large_type;
     static int toint(value_type v) { return lrintf(v); }
@@ -93,8 +98,9 @@ struct num_trait<float> {
     static const bool is_integer = false;
 };
 
-template<>
-struct num_trait<double> {
+template <>
+struct num_trait<double>
+{
     typedef double value_type;
     typedef double large_type;
     static int toint(value_type v) { return lrint(v); }
@@ -103,53 +109,55 @@ struct num_trait<double> {
     static const bool is_integer = false;
 };
 
-template<>
-struct num_trait<fixed> {
+template <>
+struct num_trait<fixed>
+{
     typedef fixed value_type;
     typedef fixed large_type;
-    static int toint(value_type v) { return (v>>15); }
-    static value_type fromdouble(double v) { return lrint(v*32768.); }
+    static int toint(value_type v) { return (v >> 15); }
+    static value_type fromdouble(double v) { return lrint(v * 32768.); }
 
     static const bool is_integer = false;
 };
 
-
-template<class A>
-static void dispatch_array(int npy_type, A& algo) {
-    switch(npy_type) {
+template <class A>
+static void dispatch_array(int npy_type, A &algo)
+{
+    switch (npy_type)
+    {
     case NPY_FLOAT32:
-	algo.template run<npy_float32>();
-	break;
+        algo.template run<npy_float32>();
+        break;
     case NPY_FLOAT64:
-	algo.template run<npy_float64>();
-	break;
+        algo.template run<npy_float64>();
+        break;
     case NPY_UINT64:
-	algo.template run<npy_uint64>();
-	break;
+        algo.template run<npy_uint64>();
+        break;
     case NPY_INT64:
-	algo.template run<npy_int64>();
-	break;
+        algo.template run<npy_int64>();
+        break;
     case NPY_UINT32:
-	algo.template run<npy_uint32>();
-	break;
+        algo.template run<npy_uint32>();
+        break;
     case NPY_INT32:
-	algo.template run<npy_int32>();
-	break;
+        algo.template run<npy_int32>();
+        break;
     case NPY_UINT16:
-	algo.template run<npy_uint16>();
-	break;
+        algo.template run<npy_uint16>();
+        break;
     case NPY_INT16:
-	algo.template run<npy_int16>();
-	break;
+        algo.template run<npy_int16>();
+        break;
     case NPY_UINT8:
-	algo.template run<npy_uint8>();
-	break;
+        algo.template run<npy_uint8>();
+        break;
     case NPY_INT8:
-	algo.template run<npy_int8>();
-	break;
+        algo.template run<npy_int8>();
+        break;
     case NPY_BOOL:
-	algo.template run<npy_bool>();
-	break;
+        algo.template run<npy_bool>();
+        break;
     }
 }
 #endif
